/***********************************************************************************
    Copyright 2008 Charles F. Gammie and Xiaoyue Guan

                        HAM  version 1.0   (released Jan 15, 2008)

    This file is part of HAM. HAM is a program that solves non-relativistic
    hyperbolic partial differential equation in conservative form using
    high-resolution shock-capturing techniques. This version of HAM has been
    configured to solve the magnetohydrodynamic equations of motion in
    axisymmetry to evolve a shearing box model.

    You are morally obligated to cite the following paper in his/her
    scientific literature that results from use of any part of HAM:

    [1] Guan, X. \& Gammie, C.F. \ 2008, Astrophysical Journal, Supplement,
        174, 145


    The latest version of the HAM is available on our code distribution
    website:
    http://rainman.astro.uiuc.edu/codelib/

    HAM is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    HAM is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with HAM; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

***********************************************************************************/

/*
 * Subroutine bounds
 *  
 * Enforce the boundary conditions on the entire
 *    	  set of primitive variables
 *
 */
#include "decs.h"

void
bounds (double (*prim_arr)[N2 + 2 * NG][NP])
{
  int i, j, k;

#if PER
  for (i = 0; i < N1; i++)
    {
      PLOOP
      {
	prim_arr[i][-1][k] = prim_arr[i][N2 - 1][k];
	prim_arr[i][-2][k] = prim_arr[i][N2 - 2][k];
	prim_arr[i][N2][k] = prim_arr[i][0][k];
	prim_arr[i][N2 + 1][k] = prim_arr[i][1][k];
      }
    }
  for (j = -NG; j < N2 + NG; j++)
    {
      PLOOP
      {
	prim_arr[-1][j][k] = prim_arr[N1 - 1][j][k];
	prim_arr[-2][j][k] = prim_arr[N1 - 2][j][k];
	prim_arr[N1][j][k] = prim_arr[0][j][k];
	prim_arr[N1 + 1][j][k] = prim_arr[1][j][k];
      }
    }
#endif
#if SHBOX
  for (i = 0; i < N1; i++)
    {
      PLOOP
      {
	prim_arr[i][-1][k] = prim_arr[i][N2 - 1][k];
	prim_arr[i][-2][k] = prim_arr[i][N2 - 2][k];
	prim_arr[i][N2][k] = prim_arr[i][0][k];
	prim_arr[i][N2 + 1][k] = prim_arr[i][1][k];
      }
    }
  for (j = -NG; j < N2 + NG; j++)
    {
      PLOOP
      {
	prim_arr[-1][j][k] = prim_arr[N1 - 1][j][k];
	prim_arr[-2][j][k] = prim_arr[N1 - 2][j][k];
	prim_arr[N1][j][k] = prim_arr[0][j][k];
	prim_arr[N1 + 1][j][k] = prim_arr[1][j][k];
      }
    }

  /* still needs shear term */
  for (j = -NG; j < N2 + NG; j++)
    {
      prim_arr[-1][j][U3] += -q * W * L1;
      prim_arr[-2][j][U3] += -q * W * L1;
      prim_arr[N1][j][U3] += q * W * L1;
      prim_arr[N1 + 1][j][U3] += q * W * L1;
    }
#endif

}
