/***********************************************************************************
    Copyright 2008 Charles F. Gammie and Xiaoyue Guan

                        HAM  version 1.0   (released Jan 15, 2008)

    This file is part of HAM. HAM is a program that solves non-relativistic
    hyperbolic partial differential equation in conservative form using
    high-resolution shock-capturing techniques. This version of HAM has been
    configured to solve the magnetohydrodynamic equations of motion in
    axisymmetry to evolve a shearing box model.

    You are morally obligated to cite the following paper in his/her
    scientific literature that results from use of any part of HAM:

    [1] Guan, X. \& Gammie, C.F. \ 2008, Astrophysical Journal, Supplement,
        174, 145


    The latest version of the HAM is available on our code distribution
    website:
    http://rainman.astro.uiuc.edu/codelib/

    HAM is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    HAM is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with HAM; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

***********************************************************************************/

#include <stdio.h>
#include <math.h>
#include <stdlib.h>

#define N1	128		/* number of zones */
#define N2	128		/* number of zones */
#define NP	7		/* number of primitive variables */
#define NG	2		/* number of ghost zones */

#define RHO	0		/* mnemonics for primitive vars */
#define U1	1
#define U2	2
#define U3	3
#define B1	4
#define B2	5
#define B3	6

extern double a_p[N1 + 2 * NG][N2 + 2 * NG][NP];	/* space for primitive vars */
extern double a_dq1[N1 + 2 * NG][N2 + 2 * NG][NP];	/* slopes */
extern double a_dq2[N1 + 2 * NG][N2 + 2 * NG][NP];	/* slopes */
extern double a_F1[N1 + 2 * NG][N2 + 2 * NG][NP];	/* fluxes */
extern double a_F2[N1 + 2 * NG][N2 + 2 * NG][NP];	/* fluxes */
extern double a_ph[N1 + 2 * NG][N2 + 2 * NG][NP];	/* half-step primitives */

extern double (*p)[N2 + 2 * NG][NP];
extern double (*dq1)[N2 + 2 * NG][NP];
extern double (*dq2)[N2 + 2 * NG][NP];
extern double (*F1)[N2 + 2 * NG][NP];
extern double (*F2)[N2 + 2 * NG][NP];
extern double (*ph)[N2 + 2 * NG][NP];

extern double L1, L2;		/* size of the grid */

extern double cour;		/* Courant Number */
extern double dx1, dx2, dV;	/* cell size */
extern double dt;		/* time step */
extern double t, tf;		/* absolute time, final time */

extern double DTd;		/* dumping frequency */
extern double DTl;		/* logfile frequency */
extern double DTi;		/* imaging frequency */

extern double W, q;		/* angular velocity profile */
extern double cs, csq;		/* sound speed */

/* choose boundary conditions.  Only one should be
   set to 1, all others to 0. 
*/
#define	PER	0		/* periodic */
#define	REF	0		/* reflecting */
#define STD	0		/* set ghost zones equal to adjacent zones */
#define SHBOX	1		/* shearing box */

/* slope limiters */
#define MINM	0
#define MC	1
#define VANL	2

#define LIM	MC

/* numerical convenience */
#define SMALL	1.e-10

/** FIXUP PARAMETERS **/
#define RHOMIN	1.e-6
#define UUMIN	1.e-8

#define LOOP for(i=0;i<N1;i++)for(j=0;j<N2;j++)
#define PLOOP for(k=0;k<NP;k++)

double ranc (int iseed);
void image (FILE * fp);
double slope_lim (double y1, double y2, double y3);
void bounds (double (*prim_arr)[N2 + 2 * NG][NP]);
void fixup (double (*pv)[N2 + 2 * NG][NP]);
