/***********************************************************************************
    Copyright 2008 Charles F. Gammie and Xiaoyue Guan

                        HAM  version 1.0   (released Jan 15, 2008)

    This file is part of HAM. HAM is a program that solves non-relativistic
    hyperbolic partial differential equation in conservative form using
    high-resolution shock-capturing techniques. This version of HAM has been
    configured to solve the magnetohydrodynamic equations of motion in
    axisymmetry to evolve a shearing box model.

    You are morally obligated to cite the following paper in his/her
    scientific literature that results from use of any part of HAM:

    [1] Guan, X. \& Gammie, C.F. \ 2008, Astrophysical Journal, Supplement,
        174, 145


    The latest version of the HAM is available on our code distribution
    website:
    http://rainman.astro.uiuc.edu/codelib/

    HAM is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    HAM is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with HAM; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

***********************************************************************************/

/* 
 * Subroutine image
 *
 * Produces an "r8" file. 
 *
 */

#include "decs.h"

#define POTVORT	0
#define DENSITY 0
#define ENERGY	0
#define CURRENT 0
#define ANGMOM	1

#define THREESIG	1
#define MINMAX		0

void
image (FILE * fp)
{
  double ymax, ymin, a, y, yfunc (int i, int j), iy;
  void scale_func (double *ymax, double *ymin);
  int i, j;

  scale_func (&ymax, &ymin);

  /* header information */
  fprintf (stderr, "max,min: %g %g\n", ymax, ymin);

  a = 255. / (ymax - ymin);

  for (j = N2 - 1; j >= 0; j--)
    for (i = 0; i < N1; i++)
      {
	y = yfunc (i, j);

	iy = a * (y - ymin);

	if (iy > 255.)
	  iy = 255.;
	if (iy < 0.)
	  iy = 0.;
	fprintf (fp, "%c", (char) ((int) iy));
      }
}

void
scale_func (double *ymax, double *ymin)
{
  double y, yfunc (int i, int j);
  double yave, ysq, ysig;
  int i, j;

#if MINMAX
  *ymax = -1.e9;
  *ymin = 1.e9;
  for (i = 0; i < N1; i++)
    for (j = 0; j < N2; j++)
      {
	y = yfunc (i, j);
	if (y > *ymax)
	  *ymax = y;
	if (y < *ymin)
	  *ymin = y;
      }
#endif

#if THREESIG
  yave = 0.;
  ysq = 0.;
  for (i = 0; i < N1; i++)
    for (j = 0; j < N2; j++)
      {
	y = yfunc (i, j);
	yave += y;
	ysq += y * y;
      }
  yave /= N1 * N2;
  ysq /= N1 * N2;
  ysig = sqrt (ysq - yave * yave);
  *ymax = yave + 3. * ysig;
  *ymin = yave - 3. * ysig;
#endif

}

double
yfunc (int i, int j)
{
  double X1, y;

#if ANGMOM
  X1 = (i + 0.5) * dx1 - 0.5 * L1;
  y = p[i][j][U3] - q * W * X1;
#endif
#if CURRENT
  y = ((p[i + 1][j][B2] - p[i - 1][j][B2]) / (2. * dx1) -
       (p[i][j + 1][B1] - p[i][j - 1][B1]) / (2. * dx2));
#endif
#if POTVORT
  y = ((p[i + 1][j][U2] - p[i - 1][j][U2]) / (2. * dx1) -
       (p[i][j + 1][U1] - p[i][j - 1][U1]) / (2. * dx2)) / p[i][j][RHO];
#endif
#if DENSITY
  y = p[i][j][RHO];
#endif
#if ENERGY
  y = p[i][j][UU];
#endif
  return (y);

}
