/***********************************************************************************
    Copyright 2008 Charles F. Gammie and Xiaoyue Guan

                        HAM  version 1.0   (released Jan 15, 2008)

    This file is part of HAM. HAM is a program that solves non-relativistic
    hyperbolic partial differential equation in conservative form using
    high-resolution shock-capturing techniques. This version of HAM has been
    configured to solve the magnetohydrodynamic equations of motion in
    axisymmetry to evolve a shearing box model.

    You are morally obligated to cite the following paper in his/her
    scientific literature that results from use of any part of HAM:

    [1] Guan, X. \& Gammie, C.F. \ 2008, Astrophysical Journal, Supplement,
        174, 145


    The latest version of the HAM is available on our code distribution
    website:
    http://rainman.astro.uiuc.edu/codelib/

    HAM is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    HAM is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with HAM; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

***********************************************************************************/

/*
 * Subroutine set_arrays
 * 
 * Construct 2D arrays for the grid functions, 
 *         so that the index of the arrays ranges 
 *         from  i = -2 to N1+1    
 *           &   j = -2 to N2+1
 *                               
 *
 */
#include "decs.h"

void
set_arrays ()
{

  p = (double (*)[N2 + 2 * NG][NP]) (&(a_p[NG][NG][0]));
  ph = (double (*)[N2 + 2 * NG][NP]) (&(a_ph[NG][NG][0]));
  F1 = (double (*)[N2 + 2 * NG][NP]) (&(a_F1[NG][NG][0]));
  F2 = (double (*)[N2 + 2 * NG][NP]) (&(a_F2[NG][NG][0]));
  dq1 = (double (*)[N2 + 2 * NG][NP]) (&(a_dq1[NG][NG][0]));
  dq2 = (double (*)[N2 + 2 * NG][NP]) (&(a_dq2[NG][NG][0]));

}
